;;; vm-url.el    makes URLs and filenames hot-links in VM mail msgs
;;;
;;; Arup Mukherjee 11/93


;;; This file provides hooks to use hot-url in vm,
;;; making hot-links out of URLs, message-ids, and/or absolute filenames.
;;;
;;; To follow one of these links, move point to it and press return,
;;; or, in lemacs, just click the middle mouse button on the link.
;;;
;;; To use this, just put
;;;      (require 'vm-url)
;;; at the end of your .vm file, and set hot-url-fetch-url-function 
;;; appropriately if you want to use Mosaic (rather than the emacs-based 
;;; w3-mode) to display the fetched URLs (see hot-url.el).
;;;
;;; The following packages are used to provide this feature:
;;;     hot-link.el             support for creating & following hot links
;;;     hot-url.el              turns urls and filenames into hot links
;;;     w3-fetch-url.el         function for using w3 to fetch a URL
;;;     mosaic-fetch-url.el     function for using NCSA Mosaic to fetch a URL

(require 'hot-url)

(if (featurep 'vm-url)
    (error "vm-url already loaded"))

;; These variables are obsolete.  Use hot-url-default-hot-types instead.
;; (defvar vm-hot-urls t
;;   "If non-nil, make URLs in mail messages into hot-links.")
;; (defvar vm-hot-msgids t
;;  "If non-nil, make message-ids (in angle brackets) in mail messages
;; into hot-links.")
;; (defvar vm-hot-filenames t
;;  "If non-nil, make absolute filenames in mail messages into hot-links.")

(defvar vm-hot-url-map nil
  "keymap for hot-url extents in VM")

;;;  default key bindings -- hit return to follow the link the cursor is on.
;;;                          in lemacs, press button2 to follow a link.

(if (fboundp 'extent-property) ;; lemacs 19.9 & later
    (progn
      (setq vm-hot-url-map (make-sparse-keymap))
      (define-key vm-hot-url-map 'button2 'hot-link-follow-mouse)
      (define-key vm-hot-url-map "\C-m" 'hot-link-follow-point))
  (setq vm-hot-url-map nil)
  (if (string-match "XEmacs\\|Lucid" (emacs-version))
      (hot-link-bind-maybe-follow-mouse vm-mode-map 'button2
					(lookup-key vm-mode-map 'button2)))
  (hot-link-bind-maybe-follow-point vm-mode-map "\C-m"
				    (lookup-key vm-mode-map "\C-m")))

(if (boundp 'vm-select-message-hook)
    ;; vm 5.40 or later
    (setq vm-select-message-hook
	  (if (listp vm-select-message-hook)
	      (append vm-select-message-hook '(vm-make-hot-urls))
	    (list vm-select-message-hook 'vm-make-hot-urls)))
  ;;
  ;; earlier versions
  ;;
  (setq vm-show-message-hook
	(if (listp vm-show-message-hook)
	    (append vm-show-message-hook '(vm-make-hot-urls))
	  (list vm-show-message-hook 'vm-make-hot-urls))))
  
(defun vm-make-hot-urls ()
  "Make URLs, message-ids, and/or absolute filenames in current buffer 
into hot-links. 
Intended for use in vm-show-message-hook."
  (hot-url-make-all-hot (point-min) (point-max) vm-hot-url-map))

(provide 'vm-url)


